module Main where

import qualified Data.Equivalence.Monad_Test

--------------------------------------------------------------------------------
-- Test Suits
--------------------------------------------------------------------------------

main = Data.Equivalence.Monad_Test.main

--------------------------------------------------------------------------------
-- Properties
--------------------------------------------------------------------------------
